from django.conf import settings
from drf_spectacular.utils import extend_schema, extend_schema_view
from rest_framework.exceptions import ValidationError
from rest_framework.generics import CreateAPIView

from arkindex.documents.serializers.admin import ReindexConfigSerializer
from arkindex.project.permissions import IsAdminUser


@extend_schema_view(post=extend_schema(operation_id='Reindex', tags=['management']))
class ReindexStart(CreateAPIView):
    """
    Manually reindex elements, transcriptions and entities for search APIs
    """
    permission_classes = (IsAdminUser, )
    serializer_class = ReindexConfigSerializer

    def post(self, *args, **kwargs):
        if not settings.ARKINDEX_FEATURES['search']:
            raise ValidationError(['Reindexation is unavailable due to the search feature being disabled.'])
        return super().post(*args, **kwargs)
