from django.contrib.contenttypes.models import ContentType
from django.db import migrations

import arkindex.users.models


def create_rights(apps, schema_editor):
    CorpusRight = apps.get_model('users', 'CorpusRight')
    Right = apps.get_model('users', 'Right')
    Corpus = apps.get_model('documents', 'Corpus')
    corpus_type_id = ContentType.objects.get_for_model(Corpus).id
    # We should user the get_for_model method
    new_rights = []
    for corpus_right in CorpusRight.objects.all():
        RoleEnum = arkindex.users.models.Role
        role = RoleEnum.Guest
        if corpus_right.can_write:
            role = RoleEnum.Contributor
        if corpus_right.can_admin:
            role = RoleEnum.Admin
        new_rights.append(Right(
            user_id=corpus_right.user_id,
            content_id=corpus_right.corpus_id,
            content_type_id=corpus_type_id,
            level=role.value
        ))
    Right.objects.bulk_create(new_rights)


class Migration(migrations.Migration):

    dependencies = [
        ('users', '0010_right_gfk'),
    ]

    operations = [
        migrations.RunPython(
            create_rights,
            reverse_code=migrations.RunPython.noop,
            elidable=True
        )
    ]
