# Generated by Django 2.2.13 on 2020-06-24 09:39

import django.db.models.deletion
from django.db import migrations, models
from enumfields import Enum


class OldDataImportMode(Enum):
    Elements = 'elements'


def populate_new_fields(apps, schema_editor):
    """
    Migrate all elements selection fields from a DataImport.payload towards new DB fields on this model
    so they can be edited later on.
    It also means that a DataImport can now be configured without being started immediately.
    """
    db_alias = schema_editor.connection.alias
    DataImport = apps.get_model('dataimport', 'DataImport')
    ElementType = apps.get_model('documents', 'ElementType')
    Element = apps.get_model('documents', 'Element')

    # Switch to Enum to restore the removed Elements import mode to allow filtering on it
    DataImport.mode.field.enum = OldDataImportMode

    for di in DataImport.objects.using(db_alias).filter(mode=OldDataImportMode.Elements):
        # There, we retrieve the payload elements that interest us to populate the new fields. We also remove the
        # attributes "ml_tools", "thumbnails" and "chunks" from the payload because they will no longer be useful.
        element, name_contains, elt_type, selection, best_class, _, _, _ = map(
            lambda key: di.payload.pop(key, None),
            (
                'element',
                'name_contains',
                'element_type',
                'elements',
                'best_class',
                'ml_tools',
                'thumbnails',
                'chunks'
            )
        )

        if name_contains:
            di.name_contains = name_contains
        if elt_type:
            try:
                di.element_type = ElementType.objects.using(db_alias).get(corpus=di.corpus, slug=elt_type)
            except ElementType.DoesNotExist:
                pass
        if element:
            try:
                di.element = Element.objects.using(db_alias).get(id=element)
            except Element.DoesNotExist:
                pass
        if selection:
            di.use_selection = True
        if best_class:
            di.best_class = best_class

        # At the end of the migration, we will find, in the payload, only elements that are not related to an Elements DataImport.
        di.save()


class Migration(migrations.Migration):

    dependencies = [
        ('documents', '0015_elementtype_allowed_transcription'),
        ('dataimport', '0010_workerversion_docker_image'),
    ]

    operations = [
        migrations.AddField(
            model_name='dataimport',
            name='best_class',
            field=models.CharField(blank=True, max_length=150, null=True),
        ),
        migrations.AddField(
            model_name='dataimport',
            name='element',
            field=models.ForeignKey(blank=True, null=True, on_delete=django.db.models.deletion.SET_NULL, to='documents.Element'),
        ),
        migrations.AddField(
            model_name='dataimport',
            name='element_type',
            field=models.ForeignKey(blank=True, null=True, on_delete=django.db.models.deletion.SET_NULL, to='documents.ElementType'),
        ),
        migrations.AddField(
            model_name='dataimport',
            name='name_contains',
            field=models.CharField(blank=True, max_length=150, null=True),
        ),
        migrations.AddField(
            model_name='dataimport',
            name='use_selection',
            field=models.BooleanField(default=False),
        ),
        migrations.RunPython(
            populate_new_fields,
            reverse_code=migrations.RunPython.noop,
        ),
    ]
